@@ -8,7 +8,7 @@
 
 int PMAP_getport(char *host,
 		 unsigned int program,
-		 unsigned int version,
-		 unsigned int protocol);
+		 unsigned int version = 1,
+		 unsigned int protocol = IPPROTO_TCP);
 
 struct pmaplist *PMAP_getmaps(char *host);
